<?php


namespace greenshiftquery\Blocks;

defined('ABSPATH') or exit;


class DynamicPostImage
{

	public function __construct()
	{
		add_action('init', array($this, 'init_handler'));
	}

	public function init_handler()
	{
		register_block_type(
			__DIR__,
			array(
				'render_callback' => array($this, 'render_block'),
				'attributes'      => $this->attributes
			)
		);
	}

	public $attributes = array(
		'id' => array(
			'type'    => 'string',
			'default' => null,
		),
		'inlineCssStyles' => array(
			'type'    => 'string',
			'default' => '',
		),
		'animation' => array(
			'type' => 'object',
			'default' => array(),
		),
		'sourceType'       => array(
			'type'    => 'string',
			'default' => 'latest_item',
		),
		'label'       => array(
			'type'    => 'string',
			'default' => '',
		),
		'postfix'       => array(
			'type'    => 'string',
			'default' => '',
		),
		'postId'       => array(
			'type'    => 'number',
			'default' => 0,
		),
		'link_enable'       => array(
			'type'    => 'boolean',
			'default' => true,
		),
		'image_size'  => array(
			'type'    => 'string',
			'default' => 'large',
		),
		'additional'  => array(
			'type'    => 'string',
			'default' => 'no',
		),
		'post_type' => array(
			'type' => 'string',
			'default' => 'h2'
		),
		'disablelazy'       => array(
			'type'    => 'boolean',
			'default' => false,
		),
		'repeaterField' => array(
			'type' => 'string',
			'default' => ''
		),
		'dynamicField' => array(
			'type' => 'string',
			'default' => ''
		),
		'dynamicType' => array(
			'type' => 'string',
			'default' => 'featured'
		),
	);

	public function render_block($settings = array(), $inner_content = '')
	{
		extract($settings);

		$additional_classes = $additional !== 'no' ? $additional : '';
		if ($disablelazy) $additional_classes .= ' no-lazyload';

		if (!empty($repeaterArray) && !empty($repeaterField)) {
			$image = !empty($repeaterArray[$repeaterField]) ? $repeaterArray[$repeaterField] : '';
			if (is_array($image)) {
				$url = $alt = '';
				if (!empty($image['sizes'][$image_size])) {
					$url = $image['sizes'][$image_size];
				} else if (!empty($image['url'])) {
					$url = $image['url'];
				}
				if (!empty($image['alt'])) {
					$alt = $image['alt'];
				}
				$image = '<img src="' . $url . '" alt="' . $alt . '" class="' . $additional_classes . '">';
			} else if (is_numeric($image)) {
				$image = wp_get_attachment_image($image, $image_size, false, ['class' => $additional_classes]);
			} else {
				$image = '<img src="' . $image . '" alt="" class="' . $additional_classes . '">';
			}
		} else {
			if ($sourceType == 'latest_item') {
				global $post;
				$postId = $post->ID;
			} else {
				$postId = (isset($postId) && $postId > 0) ? (int)$postId : 0;
			}

			$_post = gspb_get_post_object_by_id($postId, $post_type);

			if (!$_post) return __('Post not found.', 'greenshiftwoo');
			if($dynamicField && $dynamicType == 'custom'){
				$result = GSPB_get_custom_field_value($postId, $dynamicField, 'no');
				if (is_numeric($result)) {
					$result = wp_get_attachment_image($result, $image_size);
					$image = $result;
				}else{
					$image = !empty($result) ? '<img src="'.esc_url($result).'" alt="" />' : '';
				}
			}else{
				$image = get_the_post_thumbnail($postId, $image_size, ['class' => $additional_classes]);
			}
		}

		$svgimage = '<svg width="500" height="500" class="gspb_svg_placeholder" viewBox="0 0 500 500" fill="none" xmlns="http://www.w3.org/2000/svg">
    <rect width="500" height="500" fill="transparent"/>
    <g clip-path="url(#clip0_1521_865)">
    <path d="M196 262.573L226.452 231.96L285.38 291" stroke="black"/>
    <path d="M271.8 230.867C271.8 236.63 267.142 241.3 261.4 241.3C255.658 241.3 251 236.63 251 230.867C251 225.103 255.658 220.433 261.4 220.433C267.142 220.433 271.8 225.103 271.8 230.867Z" stroke="black"/>
    <path d="M259.22 264.76L282.11 241.8L305 265.853" stroke="black"/>
    </g>
    <rect x="196.5" y="209.5" width="108" height="81" stroke="black"/>
    <defs>
    <clipPath id="clip0_1521_865">
    <rect x="196" y="209" width="109" height="82" fill="white"/>
    </clipPath>
    </defs>
    </svg>';

		$image = !empty($image) ? $image : $svgimage;

		$blockId = 'gspb_id-' . $id;
		$blockClassName = 'gspb-dynamic-post-image ' . $blockId . ' ' . (!empty($className) ? $className : '') . ' ';

		$out = '<div class="' . $blockClassName . '"' . gspb_AnimationRenderProps($animation) . '>';
		if ($link_enable) {
			if (!empty($repeaterArray) && !empty($repeaterField)) {
				if (!empty($repeaterArray['link'])) {
					$out .= '<a href="' . esc_url($repeaterArray['link']) . '">';
				} else if (!empty($repeaterArray['link_to_post'])) {
					$out .= '<a href="' . esc_url($repeaterArray['link_to_post']) . '">';
				} else if (!empty($repeaterArray['ID'])) {
					$out .= '<a href="' . get_permalink($repeaterArray['ID']) . '">';
				}
			} else {
				$out .= '<a href="' . get_permalink($postId) . '">';
			}
		}
		$out .= $image;
		if ($link_enable) $out .= '</a>';
		$out .= '</div>';
		return $out;
	}
}

new DynamicPostImage;
