<?php
/**
 * Greenshift Woocommerce Helper Functions
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/* Get WooCommerce Grouped Attributes for a Product */
function gspbwoo_get_attributes_group( $product ){
    if (!is_object($product)) return;
    $attributes = apply_filters( 'woocommerce_display_product_attributes', $product->get_attributes(), $product);
    $args = array(
        'posts_per_page' => -1,
        'post_type' => 'attribute_group',
        'post_status' => 'publish',
        'orderby' => 'menu_order',
        'suppress_filters' => 0,
        'no_found_rows' => 1,
        'order' => 'ASC',
    );
    $attribute_groups = get_posts( $args );
    $temp = array();
    $haveGroup = array();

    if(!empty($attribute_groups)){
        foreach ($attribute_groups as $attribute_group) {

            // Attribut Group Name and a Key in the Group array
            $attribute_group_name = $attribute_group->post_title;
            $attribute_group_key = $attribute_group->post_name;

            // Attribut Group Image
            /*
            $attributeGroupImage = get_post_meta($attribute_group->ID, 'woocommerce_group_attributes_image' , true);
            $img = "";
            if(!empty($attributeGroupImage)){
                $img = '<img src="' . $attributeGroupImage . '" alt="' . $attribute_group_name . '" class="attribute-group-image" />';
            }
            */

            $attributes_in_group = get_post_meta($attribute_group->ID, 'woocommerce_group_attributes_attributes');

            if(is_array($attributes_in_group[0])) {
                $attributes_in_group = $attributes_in_group[0];
            } else {
                $attributes_in_group = $attributes_in_group;
            }

            if(!empty($attributes_in_group)){
                foreach ($attributes_in_group as $attribute_in_group) {

                    $attribute_in_group = wc_get_attribute($attribute_in_group);

                    foreach ($attributes as $attribute) {
                        if($attribute['is_visible'] == 0){
                            continue;
                        }

                        if(is_object($attribute_in_group) && $attribute_in_group->slug == $attribute['name']){
                            if( apply_filters( 'gspbwoo_multiple_attributes_in_groups', false ) == false ) {
                                unset($attributes[$attribute['name']]);
                            }

                            $temp[$attribute_group_key]['name'] = $attribute_group_name;
                            /* $temp[$attribute_group_key]['img'] = $img; */
                            $temp[$attribute_group_key]['attributes'][] = $attribute;
                            $haveGroup[] = $attribute['name'];
                        } else {
                            $temp[$attribute['name']] = $attribute;
                        }
                    }
                }
            }
        }
    } else {
        $temp = $attributes;
    }

    foreach ($temp as $key=>$asd) {
        if(is_array($asd)) {
            continue;
        }
        $name = $asd->get_name();
        if(!in_array($name, $haveGroup)){
            $temp['gsothergroup']['name'] = esc_html__( 'Specification', 'greenshiftwoo');
            /* $temp['other']['img'] = ''; */
            $temp['gsothergroup']['attributes'][] = $asd;
        }
        unset($temp[$key]);
    }

    return $temp;
}

////////////////////////////////////////////////////////////////////
//// Product swatches
////////////////////////////////////////////////////////////////////
function init_wc_attribute_swatches(){
    require_once 'class_wc_attribute_swatches.php';
}
add_action( 'admin_init', 'init_wc_attribute_swatches' );
if(!function_exists('gspbwoo_wc_dropdown_variation_attribute_options')){
    function gspbwoo_wc_dropdown_variation_attribute_options( $html, $args ){
        $product = $args['product'];
        $options = $args['options'];
        $taxonomy = $args['attribute'];
        $att_id = wc_attribute_taxonomy_id_by_name( $taxonomy );
        $attribute = wc_get_attribute( $att_id );

        if(!is_object($attribute)) return $html;

        $swatch_type = $attribute->type;
        if( 'select' == $swatch_type )
            return $html;

        wp_enqueue_script('gsswatches');

        if ( false === $args['selected'] && $taxonomy && $product instanceof WC_Product ) {
            $selected_key = 'attribute_' . sanitize_title( $taxonomy );
            $args['selected'] = isset( $_REQUEST[ $selected_key ] ) ? wc_clean( wp_unslash( $_REQUEST[ $selected_key ] ) ) : $product->get_variation_default_attribute( $taxonomy );
        }

        $name = $args['name'] ? $args['name'] : 'attribute_' . sanitize_title( $taxonomy );
        $output = '';

        if ( empty( $options ) && !empty( $product ) && !empty( $taxonomy ) ) {
            $attributes = $product->get_variation_attributes();
            $options = $attributes[$taxonomy];
        }
        if ( !empty( $options ) ){

            $terms = wc_get_product_terms( $product->get_id(), $taxonomy, array( 'fields' => 'all' ) );
            $output .= '<div class="gs-var-selector pb10">';

            foreach ( $terms as $term ) {
                if ( in_array( $term->slug, $options, true ) ) {

                    if($swatch_type === 'image_tag') {
                        $term_swatch_image = get_term_meta( $term->term_id, "gspbwoo_swatch_image_tag", true );
                        $term_swatch_label = get_term_meta( $term->term_id, "gspbwoo_swatch_text_tag", true );
                    } else{
                        $term_swatch = get_term_meta( $term->term_id, "gspbwoo_swatch_{$swatch_type}", true );
                    }

                    switch( $swatch_type ) {
                        case 'color':
                            $style = 'background-color:'. $term_swatch .';';
                            break;
                        case 'image':
                            $style = 'background-image:url('. esc_url( wp_get_attachment_thumb_url( $term_swatch ) ) .');';
                            break;
                        default:
                            $style = '';
                    }

                    $id = $taxonomy .'_'. $term->slug;
                    if('text' == $swatch_type){
                        $label = $term_swatch;
                        if(!$label) {
                            $label = $term->name;
                        }
                    } else if('image_tag' == $swatch_type){
                        $label = '<span class="img-bg" style="background-image: url(' . esc_url( wp_get_attachment_thumb_url( $term_swatch_image ) ) . ')"></span>';
                        $label .= '<span>' . $term_swatch_label . '</span>';
                    } else{
                        $label = '';
                        if(!$term_swatch){
                            $style = '';
                            $label = $term->name;
                            $swatch_type = 'text';
                        }
                    }

                    $output .='<input id="'. esc_attr( $id ) .'" type="radio" name="'. esc_attr( $name ) .'" value="'. esc_attr( $term->slug ) .'" '. checked( sanitize_title( $args['selected'] ), $term->slug, false ) .' class="gs-var-input" />';
                    $output .='<label for="'. esc_attr( $id ) .'" title="'. $term->name .'" class="gs-var-label '.$swatch_type.'-label-gs" style="'. $style .'" data-value="'. esc_attr( $term->slug ) .'">'. $label .'</label>';
                }
            }

            $output .= '</div>';
            $variationjs = '
            <script>
            document.querySelector("select[name='. esc_attr( $name ) .']").style.display = "none";
            for (let i = 0; i < document.querySelectorAll("input[name='. esc_attr( $name ) .']").length; i++) {
                document.querySelectorAll("input[name='. esc_attr( $name ) .']")[i].addEventListener("click", (e) => {
                    if(e.currentTarget.checked) {
                        const newValue = e.currentTarget.value;
                        const select = document.querySelector("select[name='. esc_attr( $name ) .']");
                        select.value = newValue;
                        select.dispatchEvent(new Event("change"));
                        jQuery("select[name='. esc_attr( $name ) .']").trigger("change");
                    }
                })
            }</script>';

            $output .= $variationjs;
//            wp_add_inline_script('gsswatches', $variationjs);
        }
        return $html . $output;
    }
}
if(!function_exists('gspbwoo_show_swatch_in_attr')){
    function gspbwoo_show_swatch_in_attr($wpautop, $attribute, $values){
        if(!isset($attribute['id'])) {
            return $wpautop;
        }
        $attribute_id = $attribute['id'];
        $att = wc_get_attribute( $attribute_id );
        if(!is_object($att)){
            return $wpautop;
        }
        $swatch_type = $att->type;
        if($swatch_type == 'select'){
            return $wpautop;
        }else{
            global $product;
            if(empty($product)) {
                return $wpautop;
            }
            $currentslug = $att->slug;
            $has_archive = $att->has_archives;

            $terms = wc_get_product_terms( $product->get_id(), $currentslug, array( 'fields' => 'all' ) );
            $result = '';
            foreach ( $terms as $term ) {

                if($swatch_type === 'image_tag') {
                    $term_swatch_image = get_term_meta( $term->term_id, "gspbwoo_swatch_image_tag", true );
                    $term_swatch_label = get_term_meta( $term->term_id, "gspbwoo_swatch_text_tag", true );
                } else{
                    $term_swatch = get_term_meta( $term->term_id, "gspbwoo_swatch_{$swatch_type}", true );
                }

                if(!empty($term_swatch) || !empty($term_swatch_image) || !empty($term_swatch_label)){
                    switch( $swatch_type ) {
                        case 'color':
                            $style = 'background-color:'. $term_swatch .';';
                            break;
                        case 'image':
                            $style = 'background-image:url('. esc_url( wp_get_attachment_thumb_url( $term_swatch ) ) .');';
                            break;
                        default:
                            $style = '';
                    }
                    if('text' == $swatch_type){
                        $label = $term_swatch;
                        if(!$label) {
                            $label = $term->name;
                        }
                    } else if('image_tag' == $swatch_type){
                        $label = '<span class="img-bg" style="background-image: url(' . esc_url( wp_get_attachment_thumb_url( $term_swatch_image ) ) . ')"></span>';
                        $label .= '<span>' . $term_swatch_label . '</span>';
                    }
                    else{
                        $label = '';
                    }
                    if ( $has_archive ) {
                        $result .= '<a href="' . esc_url( get_term_link( $term->term_id, $currentslug ) ) . '" rel="tag">';
                    }
                    $nonselect = $has_archive ? '' : ' label-non-selectable';
                    $result .='<span class="gs-var-label'.$nonselect.' '.$swatch_type.'-label-gs" style="'. $style .'">'. $label .'</span>';
                    if ( $has_archive ) {
                        $result .='</a>';
                    }

                }
                else{
                    return $wpautop;
                }
            }
            return $result;
        }
    }
}
if(!function_exists('gspbwoo_show_swatch_in_filters')){
    function gspbwoo_show_swatch_in_filters($term_html, $term, $link, $count){

        $attribute_id = wc_attribute_taxonomy_id_by_name( $term->taxonomy );
        if($attribute_id){
            $attribute = wc_get_attribute( $attribute_id );
            if(!empty($attribute)){
                $swatch_type = $attribute->type;
                if($swatch_type != 'select'){

                    if($swatch_type === 'image_tag') {
                        $term_swatch_image = get_term_meta( $term->term_id, "gspbwoo_swatch_image_tag", true );
                        $term_swatch_label = get_term_meta( $term->term_id, "gspbwoo_swatch_text_tag", true );
                    } else{
                        $term_swatch = get_term_meta( $term->term_id, "gspbwoo_swatch_{$swatch_type}", true );
                    }

                    if(!empty($term_swatch) || !empty($term_swatch_image) || !empty($term_swatch_label)){
                        switch( $swatch_type ) {
                            case 'color':
                                $style = 'background-color:'. $term_swatch .';';
                                break;
                            case 'image':
                                $style = 'background-image:url('. esc_url( wp_get_attachment_thumb_url( $term_swatch ) ) .');';
                                break;
                            default:
                                $style = '';
                        }
                        $attributelabel = 'text' == $swatch_type ? $term_swatch : '';

                        if('image_tag' == $swatch_type){
                            $label = '<span class="img-bg" style="background-image: url(' . esc_url( wp_get_attachment_thumb_url( $term_swatch_image ) ) . ')"></span>';
                            $attributelabel .= '<span>' . $term_swatch_label . '</span>';
                        }

                        $result = '<span class="gs-var-label label-non-selectable '.$swatch_type.'-label-gs" style="'. $style .'">'. $attributelabel .'</span>';
                        $termname = esc_html( $term->name ).'</a>';
                        $termwithswatch = $result.'<span class="gspbwoo_attr_name">'.$termname.'</span></a>';
                        $termrel = 'rel="nofollow"';
                        $termlinkclass = 'rel="nofollow" class="gspbwoo_swatch_filter gspbwoo_swatch_'.$swatch_type.'"';
                        $term_html = str_replace($termname, $termwithswatch, $term_html);
                        $term_html = str_replace($termrel, $termlinkclass, $term_html);
                    }
                }
            }
        }

        return $term_html;
    }
}
add_filter( 'woocommerce_dropdown_variation_attribute_options_html', 'gspbwoo_wc_dropdown_variation_attribute_options', 10, 2 );
add_filter('woocommerce_attribute', 'gspbwoo_show_swatch_in_attr', 10,3);
add_filter('woocommerce_layered_nav_term_html', 'gspbwoo_show_swatch_in_filters', 10, 4);